RpcTransport

Trait RpcTransport 

pub trait RpcTransport {
    // Required method
    fn call(&self, method_id: u32, payload: &[u8]) -> Result<Vec<u8>>;
}
Transport trait for making RPC calls.

Generated client stubs use this trait to send requests and receive responses, independent of whether the backing transport is shared memory or QUIC.

Required Methods

fn call(&self, method_id: u32, payload: &[u8]) -> Result<Vec<u8>>

Send a request with the given method_id and serialized payload, returning the serialized response bytes.

Implementors