pub trait RpcTransport {
// Required method
fn call(&self, method_id: u32, payload: &[u8]) -> Result<Vec<u8>>;
}Expand description
Transport trait for making RPC calls.
Generated client stubs use this trait to send requests and receive responses, independent of whether the backing transport is shared memory or QUIC.